workflow.SimpleWorkflow

|  | ## Cheshire3 Object Model: Class SimpleWorkflow

Module workflow :: Class SimpleWorkflow

## Class SimpleWorkflow
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
         baseObjects.Workflow --+
                                |
                               SimpleWorkflow

Known Subclasses:
  CachingWorkflow

Default workflow implementation. Translates XML to python and compiles it on object instantiation
Instance Methods

__init__(self, session, node, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
_handleConfigNode(self, session, node)
_handleFlow(self, node)
_handleLog(self, node)
_handleForEach(self, node)
_handleObject(self, node)
_handleSplit(self, node)
_handleFork(self, node)
Inherited from `baseObjects.Workflow`: `process` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

code |
splitN |
splitCode |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, node, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: configParser.C3Object.__init__ (inherited documentation)

### _handleConfigNode(self, session, node) | source code
Overrides: configParser.C3Object._handleConfigNode

### _handleFlow(self, node) | source code

### _handleLog(self, node) | source code

### _handleForEach(self, node) | source code

### _handleObject(self, node) | source code

### _handleSplit(self, node) | source code

### _handleFork(self, node) | source code

Class Variable Details

    ### code Value:
        None

    ### splitN Value:
        0

    ### splitCode Value:
        {}